/********************************************************************************
** Form generated from reading UI file 'qsuisettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QSUISETTINGS_H
#define UI_QSUISETTINGS_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qsuicolorschemewidget.h"

QT_BEGIN_NAMESPACE

class Ui_QSUISettings
{
public:
    QGridLayout *gridLayout_6;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout_5;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_3;
    QCheckBox *hideOnCloseCheckBox;
    QCheckBox *hiddenCheckBox;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_13;
    QLineEdit *windowTitleLineEdit;
    QToolButton *windowTitleButton;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *smoothScrollingCheckBox;
    QCheckBox *protocolCheckBox;
    QCheckBox *anchorCheckBox;
    QCheckBox *showSplittersCheckBox;
    QCheckBox *popupCheckBox;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *popupTemplateButton;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *groupBox_6;
    QVBoxLayout *verticalLayout;
    QCheckBox *numbersCheckBox;
    QCheckBox *lengthsCheckBox;
    QCheckBox *alignCheckBox;
    QSpacerItem *verticalSpacer;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_9;
    QToolBox *colorsToolBox;
    QWidget *lightModePage;
    QVBoxLayout *verticalLayout_10;
    QScrollArea *lightModeScrollArea;
    QSUiColorSchemeWidget *lightColorSchemeWidget;
    QWidget *darkModePage;
    QVBoxLayout *verticalLayout_7;
    QScrollArea *darkModeScrollArea;
    QSUiColorSchemeWidget *darkColorSchemeWidget;
    QHBoxLayout *horizontalLayout_8;
    QLabel *label_28;
    QComboBox *colorModeComboBox;
    QSpacerItem *horizontalSpacer_17;
    QPushButton *resetColorsButton;
    QWidget *tab_3;
    QVBoxLayout *verticalLayout_6;
    QCheckBox *systemFontsCheckBox;
    QWidget *widget;
    QGridLayout *gridLayout;
    QToolButton *tabsFontButton;
    QToolButton *columnFontButton;
    QLabel *tabsFontLabel;
    QLabel *plFontLabel;
    QLabel *label_2;
    QLabel *label_16;
    QLabel *columnFontLabel;
    QToolButton *plFontButton;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_7;
    QPushButton *resetFontsButton;
    QLabel *label_17;
    QLabel *label_26;
    QLabel *label_27;
    QLabel *groupFontLabel;
    QLabel *extraRowFontLabel;
    QToolButton *groupFontButton;
    QToolButton *extraRowFontButton;
    QSpacerItem *verticalSpacer_3;
    QWidget *tab_4;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox_5;
    QFormLayout *formLayout_2;
    QCheckBox *tabsClosableCheckBox;
    QCheckBox *showTabListMenuCheckBox;
    QCheckBox *showNewPLCheckBox;
    QLabel *label_25;
    QHBoxLayout *horizontalLayout_7;
    QComboBox *tabPositionComboBox;
    QSpacerItem *horizontalSpacer_14;
    QGroupBox *groupBox_7;
    QHBoxLayout *horizontalLayout_5;
    QFormLayout *formLayout;
    QLabel *label_18;
    QComboBox *toolBarIconSizeComboBox;
    QSpacerItem *horizontalSpacer_8;
    QPushButton *customizeToolBarButton;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *QSUISettings)
    {
        if (QSUISettings->objectName().isEmpty())
            QSUISettings->setObjectName("QSUISettings");
        QSUISettings->resize(687, 565);
        QSUISettings->setWindowTitle(QString::fromUtf8("Form"));
        gridLayout_6 = new QGridLayout(QSUISettings);
        gridLayout_6->setObjectName("gridLayout_6");
        tabWidget = new QTabWidget(QSUISettings);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_5 = new QVBoxLayout(tab);
        verticalLayout_5->setObjectName("verticalLayout_5");
        groupBox = new QGroupBox(tab);
        groupBox->setObjectName("groupBox");
        gridLayout_3 = new QGridLayout(groupBox);
        gridLayout_3->setObjectName("gridLayout_3");
        hideOnCloseCheckBox = new QCheckBox(groupBox);
        hideOnCloseCheckBox->setObjectName("hideOnCloseCheckBox");

        gridLayout_3->addWidget(hideOnCloseCheckBox, 0, 0, 1, 1);

        hiddenCheckBox = new QCheckBox(groupBox);
        hiddenCheckBox->setObjectName("hiddenCheckBox");

        gridLayout_3->addWidget(hiddenCheckBox, 0, 1, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_13 = new QLabel(groupBox);
        label_13->setObjectName("label_13");

        horizontalLayout_2->addWidget(label_13);

        windowTitleLineEdit = new QLineEdit(groupBox);
        windowTitleLineEdit->setObjectName("windowTitleLineEdit");

        horizontalLayout_2->addWidget(windowTitleLineEdit);

        windowTitleButton = new QToolButton(groupBox);
        windowTitleButton->setObjectName("windowTitleButton");

        horizontalLayout_2->addWidget(windowTitleButton);


        gridLayout_3->addLayout(horizontalLayout_2, 1, 0, 1, 2);


        verticalLayout_5->addWidget(groupBox);

        groupBox_2 = new QGroupBox(tab);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_3 = new QVBoxLayout(groupBox_2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        smoothScrollingCheckBox = new QCheckBox(groupBox_2);
        smoothScrollingCheckBox->setObjectName("smoothScrollingCheckBox");

        verticalLayout_3->addWidget(smoothScrollingCheckBox);

        protocolCheckBox = new QCheckBox(groupBox_2);
        protocolCheckBox->setObjectName("protocolCheckBox");

        verticalLayout_3->addWidget(protocolCheckBox);

        anchorCheckBox = new QCheckBox(groupBox_2);
        anchorCheckBox->setObjectName("anchorCheckBox");

        verticalLayout_3->addWidget(anchorCheckBox);

        showSplittersCheckBox = new QCheckBox(groupBox_2);
        showSplittersCheckBox->setObjectName("showSplittersCheckBox");

        verticalLayout_3->addWidget(showSplittersCheckBox);

        popupCheckBox = new QCheckBox(groupBox_2);
        popupCheckBox->setObjectName("popupCheckBox");

        verticalLayout_3->addWidget(popupCheckBox);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        popupTemplateButton = new QPushButton(groupBox_2);
        popupTemplateButton->setObjectName("popupTemplateButton");
        popupTemplateButton->setEnabled(false);
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("configure");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        popupTemplateButton->setIcon(icon);

        horizontalLayout_3->addWidget(popupTemplateButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);


        verticalLayout_3->addLayout(horizontalLayout_3);


        verticalLayout_5->addWidget(groupBox_2);

        groupBox_6 = new QGroupBox(tab);
        groupBox_6->setObjectName("groupBox_6");
        verticalLayout = new QVBoxLayout(groupBox_6);
        verticalLayout->setObjectName("verticalLayout");
        numbersCheckBox = new QCheckBox(groupBox_6);
        numbersCheckBox->setObjectName("numbersCheckBox");

        verticalLayout->addWidget(numbersCheckBox);

        lengthsCheckBox = new QCheckBox(groupBox_6);
        lengthsCheckBox->setObjectName("lengthsCheckBox");

        verticalLayout->addWidget(lengthsCheckBox);

        alignCheckBox = new QCheckBox(groupBox_6);
        alignCheckBox->setObjectName("alignCheckBox");
        alignCheckBox->setEnabled(false);

        verticalLayout->addWidget(alignCheckBox);


        verticalLayout_5->addWidget(groupBox_6);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout_9 = new QVBoxLayout(tab_2);
        verticalLayout_9->setObjectName("verticalLayout_9");
        colorsToolBox = new QToolBox(tab_2);
        colorsToolBox->setObjectName("colorsToolBox");
        lightModePage = new QWidget();
        lightModePage->setObjectName("lightModePage");
        lightModePage->setGeometry(QRect(0, 0, 647, 393));
        verticalLayout_10 = new QVBoxLayout(lightModePage);
        verticalLayout_10->setObjectName("verticalLayout_10");
        lightModeScrollArea = new QScrollArea(lightModePage);
        lightModeScrollArea->setObjectName("lightModeScrollArea");
        lightModeScrollArea->setWidgetResizable(true);
        lightColorSchemeWidget = new QSUiColorSchemeWidget();
        lightColorSchemeWidget->setObjectName("lightColorSchemeWidget");
        lightColorSchemeWidget->setGeometry(QRect(0, 0, 625, 371));
        lightModeScrollArea->setWidget(lightColorSchemeWidget);

        verticalLayout_10->addWidget(lightModeScrollArea);

        colorsToolBox->addItem(lightModePage, QString::fromUtf8("Light Mode"));
        darkModePage = new QWidget();
        darkModePage->setObjectName("darkModePage");
        darkModePage->setGeometry(QRect(0, 0, 104, 104));
        verticalLayout_7 = new QVBoxLayout(darkModePage);
        verticalLayout_7->setObjectName("verticalLayout_7");
        darkModeScrollArea = new QScrollArea(darkModePage);
        darkModeScrollArea->setObjectName("darkModeScrollArea");
        darkModeScrollArea->setWidgetResizable(true);
        darkColorSchemeWidget = new QSUiColorSchemeWidget();
        darkColorSchemeWidget->setObjectName("darkColorSchemeWidget");
        darkColorSchemeWidget->setGeometry(QRect(0, 0, 96, 26));
        darkModeScrollArea->setWidget(darkColorSchemeWidget);

        verticalLayout_7->addWidget(darkModeScrollArea);

        colorsToolBox->addItem(darkModePage, QString::fromUtf8("Dark Mode"));

        verticalLayout_9->addWidget(colorsToolBox);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        label_28 = new QLabel(tab_2);
        label_28->setObjectName("label_28");

        horizontalLayout_8->addWidget(label_28);

        colorModeComboBox = new QComboBox(tab_2);
        colorModeComboBox->setObjectName("colorModeComboBox");

        horizontalLayout_8->addWidget(colorModeComboBox);

        horizontalSpacer_17 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_17);

        resetColorsButton = new QPushButton(tab_2);
        resetColorsButton->setObjectName("resetColorsButton");

        horizontalLayout_8->addWidget(resetColorsButton);


        verticalLayout_9->addLayout(horizontalLayout_8);

        tabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        verticalLayout_6 = new QVBoxLayout(tab_3);
        verticalLayout_6->setObjectName("verticalLayout_6");
        systemFontsCheckBox = new QCheckBox(tab_3);
        systemFontsCheckBox->setObjectName("systemFontsCheckBox");
        systemFontsCheckBox->setChecked(true);

        verticalLayout_6->addWidget(systemFontsCheckBox);

        widget = new QWidget(tab_3);
        widget->setObjectName("widget");
        widget->setEnabled(false);
        gridLayout = new QGridLayout(widget);
        gridLayout->setObjectName("gridLayout");
        tabsFontButton = new QToolButton(widget);
        tabsFontButton->setObjectName("tabsFontButton");
        tabsFontButton->setText(QString::fromUtf8("..."));

        gridLayout->addWidget(tabsFontButton, 4, 2, 1, 1);

        columnFontButton = new QToolButton(widget);
        columnFontButton->setObjectName("columnFontButton");
        columnFontButton->setText(QString::fromUtf8("..."));

        gridLayout->addWidget(columnFontButton, 3, 2, 1, 1);

        tabsFontLabel = new QLabel(widget);
        tabsFontLabel->setObjectName("tabsFontLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabsFontLabel->sizePolicy().hasHeightForWidth());
        tabsFontLabel->setSizePolicy(sizePolicy);
        tabsFontLabel->setFrameShape(QFrame::StyledPanel);
        tabsFontLabel->setFrameShadow(QFrame::Sunken);
        tabsFontLabel->setText(QString::fromUtf8("???"));

        gridLayout->addWidget(tabsFontLabel, 4, 1, 1, 1);

        plFontLabel = new QLabel(widget);
        plFontLabel->setObjectName("plFontLabel");
        sizePolicy.setHeightForWidth(plFontLabel->sizePolicy().hasHeightForWidth());
        plFontLabel->setSizePolicy(sizePolicy);
        plFontLabel->setFrameShape(QFrame::StyledPanel);
        plFontLabel->setFrameShadow(QFrame::Sunken);
        plFontLabel->setText(QString::fromUtf8("???"));

        gridLayout->addWidget(plFontLabel, 0, 1, 1, 1);

        label_2 = new QLabel(widget);
        label_2->setObjectName("label_2");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy1);
        label_2->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        label_16 = new QLabel(widget);
        label_16->setObjectName("label_16");
        sizePolicy1.setHeightForWidth(label_16->sizePolicy().hasHeightForWidth());
        label_16->setSizePolicy(sizePolicy1);
        label_16->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(label_16, 3, 0, 1, 1);

        columnFontLabel = new QLabel(widget);
        columnFontLabel->setObjectName("columnFontLabel");
        sizePolicy.setHeightForWidth(columnFontLabel->sizePolicy().hasHeightForWidth());
        columnFontLabel->setSizePolicy(sizePolicy);
        columnFontLabel->setFrameShape(QFrame::StyledPanel);
        columnFontLabel->setFrameShadow(QFrame::Sunken);
        columnFontLabel->setText(QString::fromUtf8("???"));

        gridLayout->addWidget(columnFontLabel, 3, 1, 1, 1);

        plFontButton = new QToolButton(widget);
        plFontButton->setObjectName("plFontButton");
        plFontButton->setText(QString::fromUtf8("..."));

        gridLayout->addWidget(plFontButton, 0, 2, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer_7 = new QSpacerItem(108, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_7);

        resetFontsButton = new QPushButton(widget);
        resetFontsButton->setObjectName("resetFontsButton");

        horizontalLayout_4->addWidget(resetFontsButton);


        gridLayout->addLayout(horizontalLayout_4, 5, 0, 1, 3);

        label_17 = new QLabel(widget);
        label_17->setObjectName("label_17");
        sizePolicy1.setHeightForWidth(label_17->sizePolicy().hasHeightForWidth());
        label_17->setSizePolicy(sizePolicy1);
        label_17->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(label_17, 4, 0, 1, 1);

        label_26 = new QLabel(widget);
        label_26->setObjectName("label_26");

        gridLayout->addWidget(label_26, 1, 0, 1, 1);

        label_27 = new QLabel(widget);
        label_27->setObjectName("label_27");

        gridLayout->addWidget(label_27, 2, 0, 1, 1);

        groupFontLabel = new QLabel(widget);
        groupFontLabel->setObjectName("groupFontLabel");
        groupFontLabel->setFrameShape(QFrame::StyledPanel);
        groupFontLabel->setFrameShadow(QFrame::Sunken);
        groupFontLabel->setText(QString::fromUtf8("???"));

        gridLayout->addWidget(groupFontLabel, 1, 1, 1, 1);

        extraRowFontLabel = new QLabel(widget);
        extraRowFontLabel->setObjectName("extraRowFontLabel");
        extraRowFontLabel->setFrameShape(QFrame::StyledPanel);
        extraRowFontLabel->setFrameShadow(QFrame::Sunken);
        extraRowFontLabel->setText(QString::fromUtf8("???"));

        gridLayout->addWidget(extraRowFontLabel, 2, 1, 1, 1);

        groupFontButton = new QToolButton(widget);
        groupFontButton->setObjectName("groupFontButton");
        groupFontButton->setText(QString::fromUtf8("..."));

        gridLayout->addWidget(groupFontButton, 1, 2, 1, 1);

        extraRowFontButton = new QToolButton(widget);
        extraRowFontButton->setObjectName("extraRowFontButton");
        extraRowFontButton->setText(QString::fromUtf8("..."));

        gridLayout->addWidget(extraRowFontButton, 2, 2, 1, 1);


        verticalLayout_6->addWidget(widget);

        verticalSpacer_3 = new QSpacerItem(308, 382, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_6->addItem(verticalSpacer_3);

        tabWidget->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        verticalLayout_2 = new QVBoxLayout(tab_4);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox_5 = new QGroupBox(tab_4);
        groupBox_5->setObjectName("groupBox_5");
        formLayout_2 = new QFormLayout(groupBox_5);
        formLayout_2->setObjectName("formLayout_2");
        tabsClosableCheckBox = new QCheckBox(groupBox_5);
        tabsClosableCheckBox->setObjectName("tabsClosableCheckBox");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::SpanningRole, tabsClosableCheckBox);

        showTabListMenuCheckBox = new QCheckBox(groupBox_5);
        showTabListMenuCheckBox->setObjectName("showTabListMenuCheckBox");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::SpanningRole, showTabListMenuCheckBox);

        showNewPLCheckBox = new QCheckBox(groupBox_5);
        showNewPLCheckBox->setObjectName("showNewPLCheckBox");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::SpanningRole, showNewPLCheckBox);

        label_25 = new QLabel(groupBox_5);
        label_25->setObjectName("label_25");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_25);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        tabPositionComboBox = new QComboBox(groupBox_5);
        tabPositionComboBox->setObjectName("tabPositionComboBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(tabPositionComboBox->sizePolicy().hasHeightForWidth());
        tabPositionComboBox->setSizePolicy(sizePolicy2);

        horizontalLayout_7->addWidget(tabPositionComboBox);

        horizontalSpacer_14 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_14);


        formLayout_2->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout_7);


        verticalLayout_2->addWidget(groupBox_5);

        groupBox_7 = new QGroupBox(tab_4);
        groupBox_7->setObjectName("groupBox_7");
        horizontalLayout_5 = new QHBoxLayout(groupBox_7);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label_18 = new QLabel(groupBox_7);
        label_18->setObjectName("label_18");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_18);

        toolBarIconSizeComboBox = new QComboBox(groupBox_7);
        toolBarIconSizeComboBox->setObjectName("toolBarIconSizeComboBox");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, toolBarIconSizeComboBox);


        horizontalLayout_5->addLayout(formLayout);

        horizontalSpacer_8 = new QSpacerItem(125, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_8);

        customizeToolBarButton = new QPushButton(groupBox_7);
        customizeToolBarButton->setObjectName("customizeToolBarButton");
        customizeToolBarButton->setIcon(icon);

        horizontalLayout_5->addWidget(customizeToolBarButton);


        verticalLayout_2->addWidget(groupBox_7);

        verticalSpacer_2 = new QSpacerItem(20, 267, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        tabWidget->addTab(tab_4, QString());

        gridLayout_6->addWidget(tabWidget, 0, 0, 1, 1);


        retranslateUi(QSUISettings);
        QObject::connect(numbersCheckBox, &QCheckBox::toggled, alignCheckBox, &QCheckBox::setEnabled);
        QObject::connect(popupCheckBox, &QCheckBox::toggled, popupTemplateButton, &QPushButton::setEnabled);
        QObject::connect(systemFontsCheckBox, &QCheckBox::toggled, widget, &QWidget::setDisabled);

        tabWidget->setCurrentIndex(0);
        colorsToolBox->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(QSUISettings);
    } // setupUi

    void retranslateUi(QWidget *QSUISettings)
    {
        groupBox->setTitle(QCoreApplication::translate("QSUISettings", "Main Window", nullptr));
        hideOnCloseCheckBox->setText(QCoreApplication::translate("QSUISettings", "Hide on close", nullptr));
        hiddenCheckBox->setText(QCoreApplication::translate("QSUISettings", "Start hidden", nullptr));
        label_13->setText(QCoreApplication::translate("QSUISettings", "Window title format:", nullptr));
        windowTitleButton->setText(QCoreApplication::translate("QSUISettings", "...", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("QSUISettings", "Song Display", nullptr));
        smoothScrollingCheckBox->setText(QCoreApplication::translate("QSUISettings", "Use smooth scrolling", nullptr));
        protocolCheckBox->setText(QCoreApplication::translate("QSUISettings", "Show protocol", nullptr));
        anchorCheckBox->setText(QCoreApplication::translate("QSUISettings", "Show anchor", nullptr));
        showSplittersCheckBox->setText(QCoreApplication::translate("QSUISettings", "Show splitters", nullptr));
        popupCheckBox->setText(QCoreApplication::translate("QSUISettings", "Show popup information", nullptr));
        popupTemplateButton->setText(QCoreApplication::translate("QSUISettings", "Edit template", nullptr));
        groupBox_6->setTitle(QCoreApplication::translate("QSUISettings", "Single Column Mode", nullptr));
        numbersCheckBox->setText(QCoreApplication::translate("QSUISettings", "Show song numbers", nullptr));
        lengthsCheckBox->setText(QCoreApplication::translate("QSUISettings", "Show song lengths", nullptr));
        alignCheckBox->setText(QCoreApplication::translate("QSUISettings", "Align song numbers", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("QSUISettings", "View", nullptr));
        colorsToolBox->setItemText(colorsToolBox->indexOf(lightModePage), QCoreApplication::translate("QSUISettings", "Light Mode", nullptr));
        colorsToolBox->setItemText(colorsToolBox->indexOf(darkModePage), QCoreApplication::translate("QSUISettings", "Dark Mode", nullptr));
        label_28->setText(QCoreApplication::translate("QSUISettings", "Color mode:", nullptr));
        resetColorsButton->setText(QCoreApplication::translate("QSUISettings", "Reset colors", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("QSUISettings", "Colors", nullptr));
        systemFontsCheckBox->setText(QCoreApplication::translate("QSUISettings", "Use system fonts", nullptr));
        label_2->setText(QCoreApplication::translate("QSUISettings", "Playlist:", nullptr));
        label_16->setText(QCoreApplication::translate("QSUISettings", "Column headers:", nullptr));
        resetFontsButton->setText(QCoreApplication::translate("QSUISettings", "Reset fonts", nullptr));
        label_17->setText(QCoreApplication::translate("QSUISettings", "Tab names:", nullptr));
        label_26->setText(QCoreApplication::translate("QSUISettings", "Groups:", nullptr));
        label_27->setText(QCoreApplication::translate("QSUISettings", "Extra group row:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), QCoreApplication::translate("QSUISettings", "Fonts", nullptr));
        groupBox_5->setTitle(QCoreApplication::translate("QSUISettings", "Tabs", nullptr));
        tabsClosableCheckBox->setText(QCoreApplication::translate("QSUISettings", "Show close buttons", nullptr));
        showTabListMenuCheckBox->setText(QCoreApplication::translate("QSUISettings", "Show tab list menu", nullptr));
        showNewPLCheckBox->setText(QCoreApplication::translate("QSUISettings", "Show 'New Playlist' button", nullptr));
        label_25->setText(QCoreApplication::translate("QSUISettings", "Tab position:", nullptr));
        groupBox_7->setTitle(QCoreApplication::translate("QSUISettings", "Toolbars", nullptr));
        label_18->setText(QCoreApplication::translate("QSUISettings", "Icon size:", nullptr));
        customizeToolBarButton->setText(QCoreApplication::translate("QSUISettings", "Customize...", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_4), QCoreApplication::translate("QSUISettings", "Miscellaneous", nullptr));
        (void)QSUISettings;
    } // retranslateUi

};

namespace Ui {
    class QSUISettings: public Ui_QSUISettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QSUISETTINGS_H
