/***************************************************************************
 *   Copyright (C) 2009-2012 by Artur Guzik                                *
 *   a.guzik88@gmail.com                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef KDENOTIFYSETTINGSDIALOG_H
#define KDENOTIFYSETTINGSDIALOG_H

#include <QDialog>

namespace Ui {
    class KdeNotifySettingsDialog;
}

class KdeNotifySettingsDialog : public QDialog
{
Q_OBJECT

public:
    explicit KdeNotifySettingsDialog(QWidget *parent = nullptr);
    ~KdeNotifySettingsDialog();

public slots:
    virtual void accept() override;

private slots:
    virtual void on_templateButton_clicked();

protected:
    void changeEvent(QEvent *e) override;

private:
    Ui::KdeNotifySettingsDialog *m_ui;
    QString m_template;
};

#endif // KDENOTIFYSETTINGSDIALOG_H
