/***************************************************************************
 *   Copyright (C) 2012-2026 by Ilya Kotov                                 *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef RADIOITEMDELEGATE_P_H
#define RADIOITEMDELEGATE_P_H

#include <QStyledItemDelegate>
#include <QSize>

#define RadioButtonRole (Qt::UserRole + 1)

/*! @internal
 * @author Ilya Kotov <forkotov02@ya.ru>
 */
class RadioItemDelegate : public QStyledItemDelegate
{
    Q_OBJECT
public:
    explicit RadioItemDelegate(QObject *parent = nullptr);
    ~RadioItemDelegate();

    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
    bool editorEvent(QEvent *event, QAbstractItemModel *model,
                     const QStyleOptionViewItem &option, const QModelIndex &index) override;
    bool hasRadioButton(const QModelIndex &index) const;

private:
    QStyle *m_style;
};

#endif // RADIOITEMDELEGATE_P_H
