/********************************************************************************
** Form generated from reading UI file 'batchtageditordialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BATCHTAGEDITORDIALOG_H
#define UI_BATCHTAGEDITORDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_BatchTagEditorDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QComboBox *tagComboBox;
    QSpinBox *tagSpinBox;
    QLineEdit *tagValueLineEdit;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *BatchTagEditorDialog)
    {
        if (BatchTagEditorDialog->objectName().isEmpty())
            BatchTagEditorDialog->setObjectName("BatchTagEditorDialog");
        BatchTagEditorDialog->resize(342, 91);
        verticalLayout = new QVBoxLayout(BatchTagEditorDialog);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(6, -1, 6, 6);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        tagComboBox = new QComboBox(BatchTagEditorDialog);
        tagComboBox->setObjectName("tagComboBox");

        horizontalLayout->addWidget(tagComboBox);

        tagSpinBox = new QSpinBox(BatchTagEditorDialog);
        tagSpinBox->setObjectName("tagSpinBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tagSpinBox->sizePolicy().hasHeightForWidth());
        tagSpinBox->setSizePolicy(sizePolicy);
        tagSpinBox->setMaximum(2050);

        horizontalLayout->addWidget(tagSpinBox);

        tagValueLineEdit = new QLineEdit(BatchTagEditorDialog);
        tagValueLineEdit->setObjectName("tagValueLineEdit");

        horizontalLayout->addWidget(tagValueLineEdit);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(BatchTagEditorDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(BatchTagEditorDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, BatchTagEditorDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, BatchTagEditorDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(BatchTagEditorDialog);
    } // setupUi

    void retranslateUi(QDialog *BatchTagEditorDialog)
    {
        BatchTagEditorDialog->setWindowTitle(QCoreApplication::translate("BatchTagEditorDialog", "Change Tags of the Selected Files", nullptr));
    } // retranslateUi

};

namespace Ui {
    class BatchTagEditorDialog: public Ui_BatchTagEditorDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BATCHTAGEDITORDIALOG_H
